==========
Exceptions
==========
.. currentmodule:: polars.exceptions

.. autosummary::
    :toctree: api/
    :nosignatures:

    ArrowError
    ComputeError
    DuplicateError
    NoDataError
    NotFoundError
    PanicException
    SchemaError
    ShapeError
